@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -35,8 +33,7 @@ from google.oauth2 import service_account  # type: ignore
 from google.cloud.appengine_admin_v1.services.authorized_certificates import pagers
 from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import certificate
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import AuthorizedCertificatesTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import AuthorizedCertificatesGrpcTransport
 from .transports.grpc_asyncio import AuthorizedCertificatesGrpcAsyncIOTransport
@@ -59,7 +56,7 @@ class AuthorizedCertificatesClientMeta(type):
     def get_transport_class(
         cls, label: str = None,
     ) -> Type[AuthorizedCertificatesTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -85,7 +82,8 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -119,7 +117,8 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -136,7 +135,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -155,16 +154,17 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
     @property
     def transport(self) -> AuthorizedCertificatesTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            AuthorizedCertificatesTransport: The transport used by the client instance.
+            AuthorizedCertificatesTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -177,7 +177,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -188,7 +188,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -199,7 +199,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -210,7 +210,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -224,12 +224,12 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, AuthorizedCertificatesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the authorized certificates client.
+        """Instantiates the authorized certificates client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -284,9 +284,10 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -298,12 +299,14 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -318,8 +321,8 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -349,7 +352,6 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
             request (google.cloud.appengine_admin_v1.types.ListAuthorizedCertificatesRequest):
                 The request object. Request message for
                 `AuthorizedCertificates.ListAuthorizedCertificates`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -366,7 +368,6 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.ListAuthorizedCertificatesRequest.
         # There's no risk of modifying the input as we've already verified
@@ -412,7 +413,6 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
             request (google.cloud.appengine_admin_v1.types.GetAuthorizedCertificateRequest):
                 The request object. Request message for
                 `AuthorizedCertificates.GetAuthorizedCertificate`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -429,7 +429,6 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.GetAuthorizedCertificateRequest.
         # There's no risk of modifying the input as we've already verified
@@ -469,7 +468,6 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
             request (google.cloud.appengine_admin_v1.types.CreateAuthorizedCertificateRequest):
                 The request object. Request message for
                 `AuthorizedCertificates.CreateAuthorizedCertificate`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -486,7 +484,6 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.CreateAuthorizedCertificateRequest.
         # There's no risk of modifying the input as we've already verified
@@ -531,7 +528,6 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
             request (google.cloud.appengine_admin_v1.types.UpdateAuthorizedCertificateRequest):
                 The request object. Request message for
                 `AuthorizedCertificates.UpdateAuthorizedCertificate`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -548,7 +544,6 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.UpdateAuthorizedCertificateRequest.
         # There's no risk of modifying the input as we've already verified
@@ -588,7 +583,6 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
             request (google.cloud.appengine_admin_v1.types.DeleteAuthorizedCertificateRequest):
                 The request object. Request message for
                 `AuthorizedCertificates.DeleteAuthorizedCertificate`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -596,7 +590,6 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a appengine.DeleteAuthorizedCertificateRequest.
         # There's no risk of modifying the input as we've already verified
