@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,23 +13,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Callable, Dict, Optional, Sequence, Tuple
+from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import grpc_helpers  # type: ignore
 from google.api_core import operations_v1  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+import google.auth  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import domain_mapping
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 from .base import DomainMappingsTransport, DEFAULT_CLIENT_INFO
 
 
@@ -53,7 +50,7 @@ class DomainMappingsGrpcTransport(DomainMappingsTransport):
         self,
         *,
         host: str = "appengine.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         channel: grpc.Channel = None,
@@ -67,7 +64,8 @@ class DomainMappingsGrpcTransport(DomainMappingsTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -178,7 +176,7 @@ class DomainMappingsGrpcTransport(DomainMappingsTransport):
     def create_channel(
         cls,
         host: str = "appengine.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -209,13 +207,15 @@ class DomainMappingsGrpcTransport(DomainMappingsTransport):
             google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
+        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
+
         return grpc_helpers.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            **self_signed_jwt_kwargs,
             **kwargs,
         )
 
@@ -296,7 +296,7 @@ class DomainMappingsGrpcTransport(DomainMappingsTransport):
     @property
     def create_domain_mapping(
         self,
-    ) -> Callable[[appengine.CreateDomainMappingRequest], operations.Operation]:
+    ) -> Callable[[appengine.CreateDomainMappingRequest], operations_pb2.Operation]:
         r"""Return a callable for the create domain mapping method over gRPC.
 
         Maps a domain to an application. A user must be authorized to
@@ -318,14 +318,14 @@ class DomainMappingsGrpcTransport(DomainMappingsTransport):
             self._stubs["create_domain_mapping"] = self.grpc_channel.unary_unary(
                 "/google.appengine.v1.DomainMappings/CreateDomainMapping",
                 request_serializer=appengine.CreateDomainMappingRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_domain_mapping"]
 
     @property
     def update_domain_mapping(
         self,
-    ) -> Callable[[appengine.UpdateDomainMappingRequest], operations.Operation]:
+    ) -> Callable[[appengine.UpdateDomainMappingRequest], operations_pb2.Operation]:
         r"""Return a callable for the update domain mapping method over gRPC.
 
         Updates the specified domain mapping. To map an SSL certificate
@@ -348,14 +348,14 @@ class DomainMappingsGrpcTransport(DomainMappingsTransport):
             self._stubs["update_domain_mapping"] = self.grpc_channel.unary_unary(
                 "/google.appengine.v1.DomainMappings/UpdateDomainMapping",
                 request_serializer=appengine.UpdateDomainMappingRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["update_domain_mapping"]
 
     @property
     def delete_domain_mapping(
         self,
-    ) -> Callable[[appengine.DeleteDomainMappingRequest], operations.Operation]:
+    ) -> Callable[[appengine.DeleteDomainMappingRequest], operations_pb2.Operation]:
         r"""Return a callable for the delete domain mapping method over gRPC.
 
         Deletes the specified domain mapping. A user must be authorized
@@ -376,7 +376,7 @@ class DomainMappingsGrpcTransport(DomainMappingsTransport):
             self._stubs["delete_domain_mapping"] = self.grpc_channel.unary_unary(
                 "/google.appengine.v1.DomainMappings/DeleteDomainMapping",
                 request_serializer=appengine.DeleteDomainMappingRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["delete_domain_mapping"]
 
