@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import grpc_helpers_async  # type: ignore
 from google.api_core import operations_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
+import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
 from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import domain_mapping
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 from .base import DomainMappingsTransport, DEFAULT_CLIENT_INFO
 from .grpc import DomainMappingsGrpcTransport
 
@@ -56,7 +53,7 @@ class DomainMappingsGrpcAsyncIOTransport(DomainMappingsTransport):
     def create_channel(
         cls,
         host: str = "appengine.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -83,13 +80,15 @@ class DomainMappingsGrpcAsyncIOTransport(DomainMappingsTransport):
         Returns:
             aio.Channel: A gRPC AsyncIO channel object.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
+        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
+
         return grpc_helpers_async.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            **self_signed_jwt_kwargs,
             **kwargs,
         )
 
@@ -97,7 +96,7 @@ class DomainMappingsGrpcAsyncIOTransport(DomainMappingsTransport):
         self,
         *,
         host: str = "appengine.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         channel: aio.Channel = None,
@@ -111,7 +110,8 @@ class DomainMappingsGrpcAsyncIOTransport(DomainMappingsTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -170,7 +170,6 @@ class DomainMappingsGrpcAsyncIOTransport(DomainMappingsTransport):
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
             self._ssl_channel_credentials = None
-
         else:
             if api_mtls_endpoint:
                 host = api_mtls_endpoint
@@ -306,7 +305,7 @@ class DomainMappingsGrpcAsyncIOTransport(DomainMappingsTransport):
     def create_domain_mapping(
         self,
     ) -> Callable[
-        [appengine.CreateDomainMappingRequest], Awaitable[operations.Operation]
+        [appengine.CreateDomainMappingRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the create domain mapping method over gRPC.
 
@@ -329,7 +328,7 @@ class DomainMappingsGrpcAsyncIOTransport(DomainMappingsTransport):
             self._stubs["create_domain_mapping"] = self.grpc_channel.unary_unary(
                 "/google.appengine.v1.DomainMappings/CreateDomainMapping",
                 request_serializer=appengine.CreateDomainMappingRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_domain_mapping"]
 
@@ -337,7 +336,7 @@ class DomainMappingsGrpcAsyncIOTransport(DomainMappingsTransport):
     def update_domain_mapping(
         self,
     ) -> Callable[
-        [appengine.UpdateDomainMappingRequest], Awaitable[operations.Operation]
+        [appengine.UpdateDomainMappingRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the update domain mapping method over gRPC.
 
@@ -361,7 +360,7 @@ class DomainMappingsGrpcAsyncIOTransport(DomainMappingsTransport):
             self._stubs["update_domain_mapping"] = self.grpc_channel.unary_unary(
                 "/google.appengine.v1.DomainMappings/UpdateDomainMapping",
                 request_serializer=appengine.UpdateDomainMappingRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["update_domain_mapping"]
 
@@ -369,7 +368,7 @@ class DomainMappingsGrpcAsyncIOTransport(DomainMappingsTransport):
     def delete_domain_mapping(
         self,
     ) -> Callable[
-        [appengine.DeleteDomainMappingRequest], Awaitable[operations.Operation]
+        [appengine.DeleteDomainMappingRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the delete domain mapping method over gRPC.
 
@@ -391,7 +390,7 @@ class DomainMappingsGrpcAsyncIOTransport(DomainMappingsTransport):
             self._stubs["delete_domain_mapping"] = self.grpc_channel.unary_unary(
                 "/google.appengine.v1.DomainMappings/DeleteDomainMapping",
                 request_serializer=appengine.DeleteDomainMappingRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["delete_domain_mapping"]
 
