@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import grpc_helpers_async  # type: ignore
 from google.api_core import operations_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
+import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
 from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import version
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 from .base import VersionsTransport, DEFAULT_CLIENT_INFO
 from .grpc import VersionsGrpcTransport
 
@@ -56,7 +53,7 @@ class VersionsGrpcAsyncIOTransport(VersionsTransport):
     def create_channel(
         cls,
         host: str = "appengine.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -83,13 +80,15 @@ class VersionsGrpcAsyncIOTransport(VersionsTransport):
         Returns:
             aio.Channel: A gRPC AsyncIO channel object.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
+        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
+
         return grpc_helpers_async.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            **self_signed_jwt_kwargs,
             **kwargs,
         )
 
@@ -97,7 +96,7 @@ class VersionsGrpcAsyncIOTransport(VersionsTransport):
         self,
         *,
         host: str = "appengine.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         channel: aio.Channel = None,
@@ -111,7 +110,8 @@ class VersionsGrpcAsyncIOTransport(VersionsTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -170,7 +170,6 @@ class VersionsGrpcAsyncIOTransport(VersionsTransport):
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
             self._ssl_channel_credentials = None
-
         else:
             if api_mtls_endpoint:
                 host = api_mtls_endpoint
@@ -304,7 +303,9 @@ class VersionsGrpcAsyncIOTransport(VersionsTransport):
     @property
     def create_version(
         self,
-    ) -> Callable[[appengine.CreateVersionRequest], Awaitable[operations.Operation]]:
+    ) -> Callable[
+        [appengine.CreateVersionRequest], Awaitable[operations_pb2.Operation]
+    ]:
         r"""Return a callable for the create version method over gRPC.
 
         Deploys code and resource files to a new version.
@@ -323,14 +324,16 @@ class VersionsGrpcAsyncIOTransport(VersionsTransport):
             self._stubs["create_version"] = self.grpc_channel.unary_unary(
                 "/google.appengine.v1.Versions/CreateVersion",
                 request_serializer=appengine.CreateVersionRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_version"]
 
     @property
     def update_version(
         self,
-    ) -> Callable[[appengine.UpdateVersionRequest], Awaitable[operations.Operation]]:
+    ) -> Callable[
+        [appengine.UpdateVersionRequest], Awaitable[operations_pb2.Operation]
+    ]:
         r"""Return a callable for the update version method over gRPC.
 
         Updates the specified Version resource. You can specify the
@@ -384,14 +387,16 @@ class VersionsGrpcAsyncIOTransport(VersionsTransport):
             self._stubs["update_version"] = self.grpc_channel.unary_unary(
                 "/google.appengine.v1.Versions/UpdateVersion",
                 request_serializer=appengine.UpdateVersionRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["update_version"]
 
     @property
     def delete_version(
         self,
-    ) -> Callable[[appengine.DeleteVersionRequest], Awaitable[operations.Operation]]:
+    ) -> Callable[
+        [appengine.DeleteVersionRequest], Awaitable[operations_pb2.Operation]
+    ]:
         r"""Return a callable for the delete version method over gRPC.
 
         Deletes an existing Version resource.
@@ -410,7 +415,7 @@ class VersionsGrpcAsyncIOTransport(VersionsTransport):
             self._stubs["delete_version"] = self.grpc_channel.unary_unary(
                 "/google.appengine.v1.Versions/DeleteVersion",
                 request_serializer=appengine.DeleteVersionRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["delete_version"]
 
